package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````HA4``#0`````D0```````#0`(``*
M`"@`%P`6``8````T````-````#0```!``0``0`$```0````$`````P```'0!
M``!T`0``=`$``!<````7````!`````$````!````````````````````;`\`
M`&P/```$`````!````$`````$````!`````0```I*@``*2H```4`````$```
M`0````!`````0````$```+!*``"P2@``!``````0```!````](T``/2=``#T
MG0``,`(``(`2```&`````!````(````$C@``!)X```2>``#0````T`````8`
M```$````4.5T9$Q]``!,?0``3'T``/0```#T````!`````0```!1Y71D````
M```````````````````````&````$````%+E=&3TC0``])T``/2=```,`@``
M#`(```0````!````+VQI8B]L9"UM=7-L+6DS.#8N<V\N,0``$0```$D````(
M````"``````0$``E0`2`*``0!*"&`(2``0``"R`$"3B`$D&*!`@(`````$D`
M``!-````40```%(```!8````60```%H`````````7````%T`````````7@``
M`%\```!A``````````````!J?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-\0[49-1\
M(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'XD?&`;OCDGQ5PSS29Z_,9H@'<--#
M1=7L,V+;[16,)<Q_J9R;X*<""FL:GE"CX/M)``````````````````````P`
M`````````````!(```"N`0`````````````2````%```````````````$0``
M`-0!`````````````!$```!0`0`````````````2````&P``````````````
M$@```(T!`````````````!(````C```````````````2````*@``````````
M````$@```.$!`````````````!(```"9`0`````````````2````(`,`````
M````````(0```#,``````````````!(````Y```````````````2````0```
M````````````$@```.T"`````````````!(```#>`@`````````````2````
M9@(`````````````$@````<"`````````````!(```!'```````````````2
M````FP(`````````````$@```$X``````````````!(```!6````````````
M```2````A`(`````````````$@```%X``````````````!(```!D````````
M```````2````;0``````````````(````-<"`````````````!(```")````
M```````````2````C@``````````````$@```/(!`````````````!$```"B
M`@`````````````2````-`(`````````````$@```)4``````````````!(`
M``"<```````````````@````)@(`````````````$@```%4#````````````
M`!(```"M`@`````````````1````'P,`````````````$0```%@"````````
M`````!(````,`P`````````````2````(0,`````````````$0```+H`````
M`````````!(````$`P`````````````2````7@$`````````````$@```,,`
M`````````````"(```#2```````````````2````SP(`````````````$@``
M`$0"`````````````!(```#7```````````````2````W0``````````````
M(````(\"`````````````!(```#W```````````````2````?@$`````````
M````$@```/P``````````````"`````8`0`````````````2````=`(`````
M````````$@```&T!`````````````!(````>`0`````````````2````+P$`
M````````````$@````("`````````````!(```!?```````````````2````
M$P(`````````````$@```$T"`````````````!(```#]`@`````````````2
M````-0$`````````````$@```/4"`````````````!(```#]`0``````````
M```2````O`$`````````````$@```"D#`````````````!(````>`P``````
M```````A````20$`````````````$@```!D#``#($P``V@$``!(`"@#.`0``
M'3H```$````2``L`EP,``&@B``##!0``$@`*`$,$```G*P``7@```!(`"@!T
M`P``8QT```4````2``H``00````0```!````$@`'`+H#```K*```_`(``!(`
M"@`G!```:!T``+T!```2``H`\@,``"2@````````$``4`(4#``"Y(0``KP``
M`!(`"@"D`P``^!L``#L````2``H`K`,``$0A``!*````$@`*`-`#``"W-P``
M_P```!(`"@#E`P``)1\``!4````2``H`/@0``'2P````````$``4`#H#``"]
M%0``-P```!(`"@`'!```.A\``*X````2``H`VP,``""@```$````$0`3`"`$
M```DH````````!``$P#W`P``HA4````````0``H`_@,``&4W``!2````$@`*
M`$,#``".(0``*P```!(`"@!>`P``B!P``-L````2``H`-`0``+8X```G`0``
M$@`*`!,$``#H'P``7`$``!(`"@``;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!L<V5E:P!G971P:60`<W1R8VUP
M`'5N;&EN:P!M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D
M97)E9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!?7V1E
M<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R96%D;&EN:P!?7V-X85]F:6YA
M;&EZ90!E>&ET`&-L;W-E`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`<F5A
M9`!?7W)E9VES=&5R7V9R86UE7VEN9F]?8F%S97,`<FUD:7(`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&=E='5I9`!097)L
M7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`
M4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G<P!?9FEN:0!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!0
M97)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!0
M97)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R
M=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`
M4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``
M;&EB8RYM=7-L+7@X-BYS;RXQ`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F
M;W)K`')E861D:7(`<W!R:6YT9@!S=')T;VL`<W1R;F-P>0!?7VQI8F-?<W1A
M<G1?;6%I;@!?7U]E;G9I<F]N`%]?<W1A8VM?8VAK7V9A:6P`7W-T87)T7V,`
M9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R7VUK
M=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?8G-S
M7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A
M=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?96YD`'!A<E]C;&5A;G5P`"]U
M<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`````,"?```(````S)\```@`
M``#4GP``"`````"@```(````!*````@````(H```"`````R@```(````$*``
M``@````4H```"````""@```(````Q)\```8#``#(GP``!@0``-"?```&&P``
MV)\```8?``#<GP``!B,``."?```&)@``Y)\```8J``#HGP``!BX``.R?```&
M,P``\)\```8W``#TGP``!CD``/B?```&.@``_)\```8_``#@G@``!P$``.2>
M```'`@``Z)X```<%``#LG@``!P8``/">```'!P``])X```<(``#XG@``!PD`
M`/R>```'"@```)\```<+```$GP``!PT```B?```'#@``#)\```</```0GP``
M!Q```!2?```'$0``&)\```<2```<GP``!Q,``""?```'%```))\```<5```H
MGP``!Q8``"R?```'%P``,)\```<8```TGP``!QD``#B?```'&@``/)\```<<
M``!`GP``!QT``$2?```''@``2)\```<@``!,GP``!R$``%"?```'(@``5)\`
M``<D``!8GP``!R4``%R?```'*```8)\```<I``!DGP``!RL``&B?```'+```
M;)\```<M``!PGP``!R\``'2?```',```>)\```<Q``!\GP``!S(``("?```'
M-```A)\```<U``"(GP``!S8``(R?```'.```D)\```<[``"4GP``!SP``)B?
M```'/0``G)\```<^``"@GP``!T```*2?```'00``J)\```="``"LGP``!T,`
M`+"?```'1```M)\```=%``"XGP``!T8``+R?```'2```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`(/L#.CX!@``Z.DI``"#Q`S#````````````````````_[,$````_Z,(````
M`````/^C#````&@`````Z>#_____HQ````!H"````.G0_____Z,4````:!``
M``#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@_____Z,@````
M:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.````.EP_____Z,L
M````:$````#I8/____^C,````&A(````Z5#_____HS0```!H4````.E`____
M_Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT````!H:````.D0
M_____Z-$````:'````#I`/____^C2````&AX````Z?#^____HTP```!H@```
M`.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^____HU@```!H
MF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````Z9#^____HV0`
M``!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`````Z6#^____
MHW````!HR````.E0_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^
M____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^CA````&CP````
MZ0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(
M`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG```
M`&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^C
MJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W_
M__^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I
M(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!
M``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````
M:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@
M````:*@!``#ID/S___^CY````&BP`0``Z8#\____H^@```!HN`$``.EP_/__
M_Z,(`0``9I#_HQ0!``!FD/^C'`$``&:0C4PD!(/D\/]Q_(U!"%6)Y5=6B<Y3
MZ!("``"!P_**``!1@^P,4(U!!%!1Z&G^__^+@R@!``"#Q`Q04/^S)`$``.CS
M_/__BX/T````@\00B[L$`0``@#@`=33HJOW__XF#G!$``(7`=0J#[`QJ`>@V
M_O__@^P,4.B-_O__6?\WZ`7___^#Q!#&@#T&````@^P,_S?H\?[__X"(G@(`
M``):_S?HXO[__X/$$("(G@(```&+!H/`!3W___\_=A104(V#G:'___^S#`$`
M`%#H&/S__X/L#,'@`E#H#/[__XM^!(/$$+D!````B8.0$0``QX.4$0``!```
M`(L7B1"-D^&C__^)4`2+DTP!``")4`B-D^2C__^)4`R+%CG*?@J+-(^)=(@,
M0>OR@^P,QT20#`````"#P@-J`%"-@U]]__]24/^SG!$``.A>_/__@\0@B<:%
MP'43@^P,_[.<$0``Z&?]__^#Q!")QH/L#/^SG!$``.CD_/__C8/KH?__Z)0"
M``"#Q!"%P'4P@[N8$0```'41C8.@H?__Z'D"``")@Y@1``"+@Y@1``"%P'0,
M@^P,4.BL%0``@\00@^P,_[.<$0``Z.3]___HO_K__X/$$(UE\(GP65M>7UV-
M8?S#,>V)X(/D\%!0Z`````"!!"14B```4.@`````4^@Q````@<,1B0``@^P0
MBT0D&&H`C5`$_[/X````_[,``0``4O\P_[/L````Z$'\__^#Q"A;PXL<),/H
M2@$```77B```C8A0`0``C9!0`0``.<IT&(N`_````(7`=`Y5B>6#[!11_]"#
MQ!#)P\/H&P$``('!I(@``%6)Y5:^`@```%.-F5`!``"-@5`!```IV,'X`IGW
M_H7`=!.+D1@!``"%TG0)45%04__2@\00C67X6UY=PU6)Y5=64^AW____@<-7
MB```@^P,@+ML`0```'5I@[L4`0```'01@^P,_[,L`0``Z!+]__^#Q!"-LRC_
M__^-NRS___\I]\'_`D^+@W`!```Y^',,0(F#<`$``/\4ANOJZ"+___^#NP@!
M````=!*#[`R-@[S?__]0Z,+\__^#Q!#&@VP!```!C67T6UY?7<-5Z`````!:
M@<+.AP``B>53Z-_^__^!P[^'``!0@[L<`0```'09C8-T`0``4FH`4(V#O-__
M_U#HA?S__X/$$(M=_,GIY/[__XL$),.+#"3#55=6,?93Z)K^__^!PWJ'``"#
M[!R)5"0$A<!T9HG!BX,0`0``,?:)S8L0A=)T5(I%`(3`=`<\/70#1>OR*<V)
MUXLWA?9T/(E4)`Q055&)3"045NBZ^?__@\00BTPD"(M4)`R%P'47@#PN/741
MBT0D!"G7C70N`<'_`HDXZP6#QP3KOH/$'(GP6UY?7<.#[!QEBPT4````B4PD
M##')C50D".A;____BTPD#&4S#10```!T!>C7(0``@\0<P^AV$P``@<+%A@``
M5E.)PX/L%&6A%````(E$)`PQP(NR$`$``(U4)`B)V.@6____A<!T%XL&BU0D
M"(T$D(M0!(D0A=)TWX/`!.ORBT0D#&4S!10```!T!>AW(0``@\046U[#55=6
M4^A__?__@<-?A@``@^PLB00DB50D!&6A%````(E$)!PQP(`Z/74$_T0D!(/-
M_S'V_(M\)`2)\(GIC50D&/*N]]&-0?^)1"0(BP0DZ)#^__^)PH7`="^)Z8G'
MB?#RKHG-]]5-.VPD"`^"J@```#'`BWPD!(H,!X@,`D"$R77Q,<#I#@$``(N#
M$`$``#'VBQ"#/+(`=`-&Z_>#NXP1````C3RU"````'0@45%74NA`]___BY,0
M`0``@\00B0*%P'5#@\C_Z<L```")5"0,@^P,5\>#C!$```$```#H\O?__X/$
M$(G%A<!TV%"-1_A0BU0D%%)5Z.GW__^+@Q`!``"#Q!")*(N#$`$``(L`QT0X
M_`````")="08BP0DBA"$TG0(@/H]=`-`Z_*+LQ`!``"+3"08@^P,*T0D#(L6
MC3R*BTPD%(U$`0)0Z(7W__^#Q!")!X7`#X1G____BP:+5"08BP20_P0DBSPD
MB<%`BE?_B%#_@/H]=`2$TG7HQ@$],=*+="0$B@P6B`P00H3)=?'IZ_[__XM\
M)!QE,ST4````=`7HR1\``(/$+%M>7UW#55=6B<93Z,W[__^!PZV$``"![(P`
M``!EH10```")1"1\,<"%]@^$&0$``(`^``^$$`$``(/L#%;HU_7__X/$$(G%
MA<`/A/H```"-@U>A__^)1"0(C8-6H?__B40D#(/L#%7H;?;__X/$$(7`#X2^
M````@\`3B00D4E+_="00_W0D#.@]]O__@\00A<!TT%!0_W0D%/]T)`SH)_;_
M_X/$$(7`=+J#RO\QP/R)T8GW@^P,\JZ+?"0,]]&)3"00B=&+5"00\JZ)R/?0
MC0P"4>A2]O___W0D$(G'C8-9H?__5E!7Z%[X__^#Q!B-1"0D4%?H$/C__X/$
M$$!T&8M$)"PE`/```#T`0```=0F)^.CO_O__ZPR#[`Q7Z/CU__^#Q!"#[`Q7
MZ,SW__^#Q!#I+O___X/L#%7H._;__XDT).B#]___@\00BT0D?&4S!10```!T
M!>AK'@``@<2,````6UY?7<-6B<93Z&[Z__^!PTZ#``"#['QEH10```")1"1T
M,<"-1"044%;HVO7__X/$$(7`=3&+5"0<@>(`\```@?H`0```=`B!^@"@``!U
M&5!0:@)6Z*_T__^#Q!"%P`^4P`^VP.L",<"+3"1L93,-%````'0%Z.L=``"#
MQ'1;7L-3Z/;Y__^!P]:"``"#[!2+@P0!``#_,.@\]___C9-LWO__4HV37Z'_
M__^S(`$``%)0Z`+W__^#Q"A;PU93Z+KY__^!PYJ"``"#[!"+LP0!``#_-N@`
M]___B00DZ*#___]8_S;H\/;__UE>:@")PHV#X*/__U!0C8-7B?__4(V#>Z'_
M_U!2Z![T__^#Q"1;7L-55U93Z&/Y__^!PT."``"![!P@``!EH10```")A"0,
M(```,<#H'_3__X/L#(V3D*'__U)0C8.4H?__4&@!$```C6PD)E7HOO/__X/$
M((U0`8'Z`1```'8"#PN%P'D$,<#K65!H`!```(VT)!,0``!65>A"]?__@\00
MB<6%P'C?@^P,C4`!4.@M]/__@\00A<!TS#GP<P>-%"@YUG*[.?!V!XT4+CG0
M<K"!_0$0``!_J/R)QXGI\Z3&!"@`BXPD#"```&4S#10```!T!>B%'```@<0<
M(```6UY?7</I(/___U575E/H@_C__X'#8X$``('LG!```(N4)+00``"+M"2P
M$```B50D$&6A%````(F$)(P0```QP(V#H*'__^@R^O__B40D#%!0:B]6Z#GT
M__^#Q!"+5"00A<!T$HGRC8.IH?__Z)WZ___I+P$``/PQP(/)_XGWC:NVH?__
M\J[WT8U!_XE$)!!04%52Z$KU__^#Q!")PHV#5Z'__XE$)!2-@[BA__^)1"08
MA=)TKX`Z`'4$BU0D%(-\)`P`=!]04%*)5"0H_W0D&.BM\O__@\00BU0D'(7`
M#X2M````@\G_,<")U_*N]]%)@'P*_R]U!TG&!`H`Z_*+1"00C40(`3W_#P``
M#X]3____C8.)HO__5U=6_W0D)%)0:``0``"-O"2H````5^@`\O__@\0@0#T`
M$```=@(/"U%1C40D-%!7Z';T__^#Q!"%P'4^BT0D/"4`\```/0"```!U+E)2
M:@%7Z+7Q__^#Q!"%P'4=B?J-@ZFA___HC?G__X/L#%?HN/+__X/$$(G&ZQ10
M4%5J`.A']/__@\00B<+I#/___XN$)(P0``!E,P44````=`7HQ1H``('$G!``
M`(GP6UY?7<.+5"0$B="*"H3)=`A"@/DO=?3K\,-75E.+5"00Z*[V__^!PXY_
M``"%TG0\@#H`=#?\,<"#R?^)U_*N]]&-1`K^.<)S&H`X+W4'2.OT.<)S#HH(
MB<9(@/DO=?*)\.LM.<)U*8`Z+W4+@^P,C8-7H?__ZPF#[`R-@[BA__]0Z/KQ
M__^#Q!#K.8`X+W4%2#G"<O8IT(U(`H'Y`!```'<@0#T`$```=@(/"XVSC`$`
M`%%04E;H=?+__X/$$(GPZP(QP%M>7\-7N2(```!64^C_]?__@</??@``@^PP
M9:$4````B40D+#'`C7PD"HVS2-[___SSI(V#NJ'__^CH]___C8/#H?__Z-WW
M__^-@\NA___HTO?__XV#U*'__^C']___C8/;H?__Z+SW__^-@^NA___HL??_
M_XV#H*'__^BF]___C8/WH?__Z)OW__^-@P&B___HD/?__XV#"Z+__^B%]___
MC8.IH?__Z'KW__^-@Q6B___H0/?__X7`=`V)PHV#`:+__^C`]___C8,FHO__
MZ"3W__^)PH7`=`N-@S&A___HI/?__XV#.*+__^@(]___B<*-@Z"A__^%TG4V
MC8-(HO__Z/'V__^)PH7`=1]0C8-9HO__:@I0C40D)U#H7/#__X/$$(7`=0^-
M5"0EC8/WH?__Z%+W__^-DV2B__^-@]NA___H0??__XM$)"QE,P44````=`7H
MH!@``(/$,%M>7\-3Z*KT__^!PXI]``"#[`B#NT@!``#_=2>-@_>A___H=/;_
M_S'2A<!T$(H`/#`/E<$QTH3`#Y7"(<J)DT@!``"+@T@!``"#Q`A;PU/H8/3_
M_X'#0'T``(/L".C^\?__@^P,4.AE\/__@\00A<!T`HL`@\0(6\-55U93Z#+T
M__^!PQ)]``"#[!R+="0PC8-FHO__Z`'V__^%P'0'@#@`B<5U#8GRC8-FHO__
M@\0<ZV504%95Z,7O__^#Q!"%P'5>@\K__(G1B?>#[`SRKHGO]]&)3"08B='R
MKHM\)!B)R/?0C0P'4>@4[___B2PDB<*-@[:A__]0C8.)HO__5E!2B50D+.@6
M\?__BU0D+(V#9J+__X/$/%M>7UWI#/;__X/$'%M>7UW#5;D&````5U93Z'[S
M__^!PUY\``"![/R```!EH10```")A"3L@```,<"+K"00@0``C;PDE````,>$
M)(0`````````C8,LH?__C;,P`0``B40D?(V#5Z'__XF$)(````#\\Z6-@TBA
M___'A"20`````````(F$)(@```"-@TVA__^)A"2,````C8.@H?__Z.'T__^%
MP'0A@#@`B<9T&H/L#%#HJ_[__XDT).B*[O__B40D$.GF!```Z&K^__^-O"2(
M````B<:%P'4SBP>%P'0GZ)_T__^%P'4%@\<$Z^R`.`!T]H/L#%#H3>[__X/$
M$(G&A<!TY.L&C;-VHO__,<")]X/)_X/L#/*N]]&-1`G_4.C$[?__C9-]HO__
MB40D$(G'@\00#[8&A,!T&E%&4%*)5"005X/'`NB][___@\00BU0D!.O?C;PD
ME````(LWA?9T*8GPZ!OT__^)QH7`="*`.`!T'>BM]___A<!T%(/L#%;HP^W_
M_X/$$(G&C7PD?.LT@\<$Z\:+%X72="V`.@!T*(G0B50D!.AZ]___BU0D!(7`
M=`Z#[`Q2Z(SM__^#Q!")QH/'!(7V=,TQP(/)_XGW@^P,\JZ+?"0,B<J#R?_R
MKO?2B<CWT(V\`@($``!7Z/;L__^)1"046(V#@J+__UK_="0(4(V#N*'__XE$
M)!A0C8.'HO__5E#_="0@Z.GN__^#Q!AHP`$``/]T)!#H>.[__X/$$$!U,.A=
M[O__BP"#^!%T)(/L#%"-@Y"B____="04_W4`4(N#\````/\PZ,?M__^#Q"#K
M/%96C40D)%#_="00Z++L__^)1"0<@\00@WPD#`!T*HV#RZ+___]T)`3_=0!0
MBX/P````_S#HB>W__X/$$,<$)`````#I`@,``(M$)"PE`/```#T`0```=<:+
M="0TZ('N__\YQG6YBT0D+"7_`0``/<`!``!UJ8/L#%?H!.S__XE$)!"-@W&B
M___HD/+__X/$$(7`=06+=0#K'8/L#%#H0.S__UI94/]U`.C]]___@\00B<:%
MP'3>B?>#R?\QP/*N]]&->?^#_P-V7%!0C8,>H___4(U$#OM0Z$;K__^#Q!"%
MP'5"@_\$=`>`?#[[+W4VBVT$A>UT+S'`@\G_B>_RKO?1C4'_@_@#=AQ04(V#
M(Z/__U"-1`W[4.@&Z___@\00A<!U`HGNZ%S[__^)Q87`#X5F`0``4%!J`%;H
MM.O__X/$$(G&A<`/A$\!``!J`FK_:NY0Z*OJ__^#Q`QJ!HV\)/0```!75NB8
M[/__@\00@+PD[`````!U78"\).T```!#=5.`O"3N````075)@+PD[P```$-U
M/X"\)/````!(=36`O"3Q````174K:@)J_VK&5NA-ZO__@\0,:BE75NA![/__
MC8/@H___7EU05_]T)!CIJ@```&H`:@!J`%;H(NK__^C"$```B<>#Q!!1:`"`
M``"-E"3T````4HE4)!16Z`#L__^#Q!"+5"0(A<!^"U%04E?HXQ```.O/@^P,
M5NC!Z___6%I7C;0DNP```%;HQQ$``(/$$(V3?:+__U`/M@0N4(U$+0!%4HV\
M),\```")5"04`?A0Z$GL__^#Q!"#_12+5"0(==6-@^"C___&A"3K`````%55
M4(V#N*'__U=0C8,HH____W0D&%#_="0<Z!#L__^#Q"#IB````(V39*+__XV#
M]Z'__^@#\?__C;O@H___Z%SI__]65HVS1:/__U=0C8,WH____W0D&/]T)!A0
M_W0D'.C*Z___@\0@4E)HP`$``/]T)`SH5^O__X/$$$!U,>@\Z___@S@1=2?_
M1"0,Z`[I__]15_]T)!10_W0D&/]T)!A6_W0D'.B%Z___@\0@Z[F#[`S_="00
MZ"3K__^+5"00C8.@H?__Z''P__]8_W0D#.BT^?__@\00BX0D[(```&4S!10`
M``!T!>C`$0``BP0D@<3\@```6UY?7<-55U93Z,#M__^!PZ!V``"#["B+LP0!
M``#_-N@&Z___7?\VB<?H_.K__XI79(A098V#VZ'__^AV[___@\00A<!T"X`X
M,74&@'@!`'0%Z&SW__^#[`S_-NC*ZO__C9-6H___:@MJ`5)0Z$GI__^#Q""%
MP'4M@^P,_S;HJ.K__XV36Z/__VH#:@%24.@GZ?__@\0@B<>%P`^%S````.D+
M`0``BT`,OP$```"+:!B-1_^)1"0(BP8YNY01``!^'8/L#%#H8.K__VH`_W0D
M'%50Z!/H__^#Q""%P'44BX.4$0``2#M$)`AUC;\!````ZU2+$(M"""4`!"``
M/0`$``!U!8M"#.L@B50D#(/L#/\VZ!3J__]J`FH`BU0D)%)0Z#7J__^#Q"!1
M45"+@Y`1``#_-+CH@>?__X/$$(7`=9Y'Z6K___^+!CF[E!$```^.)/___X/L
M#$=0Z,SI__]96E50Z+/F__^#Q!#KVHM`#(/L#(LH_S;HK^G__X/$#(V37:/_
M_U)54.A.Z/__BT<,@\00BSCV1PI`=!:#[`S_-NB&Z?__75I74.A-Y___@\00
M@^P,_S;H<.G__XV38J/__VH#:@%24.COY___@\0@B<6%P'1GC8.IH?__Z-;M
M__^)QX7`=`6+10SK-^AS\O__A<")QXM%#'0A@^P,BRC_-N@FZ?__@\0,5U50
MZ,OG__^)/"3HT^C__^L?BY.0$0``BSJ+*(/L#/\VZ/WH__^#Q`Q755#HHN?_
M_X/$$(/L#/\VZ.7H__^#Q`R-DV2C__]J`5)0Z//E__]:_S:)Q^C)Z/__@\0,
MC9-YH___4E=0Z&CG__]9_S;HL.C__\9`90"-@Z"A___H+.W__X/$$(F#F!$`
M`(7`=2:#[`S_LY`1``#HGO?__X/$$(F#F!$``(7`=0N#[`R-@W^C___K-U!0
M:,`!``#_LY@1``#H#.C__X/$$(U0`8/Z`78@@_@1=!M0BX.0$0``_[.8$0``
M_S"-@Z"C__]0Z)'E__^#Q!Q;7E]=PU=64XMT)!#HP>K__X'#H7,``(/L#%;H
M^//__XD$).C;\___@\00B<?H\/7__X7`="F%]G0E@#X`="!04(V#@J+__U!7
MZ%#F__^#Q!`YQW4*6XGP7E_IF^[__UM>7\.+%"3#53'25U93@>Q\`0``B40D
M"&6A%````(F$)&P!```QP(M$)`B+3)`<C40D+`_)B0R00H/Z$'7IC8PD+`$`
M`(M0-#-0((/`!#-0!#-0_-'"B5`\.<AUZ(M$)`B+`(E$)!"+1"0(BU0D$(M`
M!,'*`HE$)!B+1"0(BTPD&(M`",')`HE$)`R+1"0(BWPD#(ML)`R+0`PQSR-\
M)!`S?"0,B40D%(M$)`B+0!")1"0<BT0D+(M<)!R-M`.9>8):BT0D$(M<)!3!
MP`4!\(MT)`PS="04(W0D&#-T)!0!QHM$)#"-A`.9>8):B<L!QXGP,=/!P`4A
M\\'.`@''BT0D-#'+C80%F7F"6HML)#@!PXGXP<`%C8PIF7F"6HML)#P!PXG0
M,?`A^,'/`C'0C90JF7F"6HML)$`!R(G9P<$%`<B)\3'Y(=DQ\8VT+IEY@EJ+
M;"1$`=&)PL'"!<'+`@'1B?HQVB'"P<@",?J-O"^9>8):BVPD2`'RB<[!Q@4!
M\HG&B=@Q\"'(,=B-G"N9>8):BVPD3`'XB=?!QP4!^(G/B?'!SP(Q^2'1,?&-
MM"Z9>8):BVPD4`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-O"^9>8):BVPD
M5`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD6`'XB=?!QP4!^(G/B?'!
MSP(Q^2'1,?&-M"Z9>8):BVPD7`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-
MO"^9>8):BVPD8`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD9`'XB=?!
MQP4!^(G/B?'!SP(Q^2'1,?&-M"Z9>8):`=F)P\'#!0'9B=.)^L'+`C':(<+!
MR`(Q^HG%B=@!\HG.,>C!Q@4AR,')`@'RBW0D:#'8C;0WF7F"6HGO`?")UC'/
MP<8%(=?!R@(!\(MT)&PQ[XV<,YEY@EJ)S@'?B<,QUL'#!2'&P<@"`=^+7"1P
M,<Z-G!V9>8):BVPD=`'>B?O!PP6-C"F9>8):BVPD>`'>B=,QPR'[,=/!SP*-
ME"J9>8):`<N)\<'!!0'+B<$Q^2'QP<X",<$!T8G:P<(%`=&+5"1\C800H>O9
M;HGZ,?(QVL'+`@'"B<C!P`4!PHN$)(````"-O`>AZ]ENB?`QV#'(`?B)U\''
M!0'XB<^+C"2$````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DB```
M`,'.`HV<$Z'KV6Z)^C'R,<(!VHG+P<@"P<,%`=J)PXN$)(P```"-O`>AZ]EN
MB?`QV#'(`?B)U\''!0'XB<^+C"20````P<\"C;0.H>O9;HG9,?DQT0'QB<;!
MQ@4!\8G6BY0DE````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$
M))@```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2<````P<\"C;0.H>O9
M;HG9,?DQT0'QB<;!Q@4!\8G6BY0DH````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!
MVHG+P<,%`=J)PXN$)*0```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2H
M````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DK````,'.`HV<$Z'K
MV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+````"-O`>AZ]ENB?`QV#'(`?B)
MU\''!0'XB<^+C"2T````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0D
MN````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+P```"-O`>A
MZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"3`````P<\"C;0.H>O9;HG9,?DQT0'Q
MB<;!Q@4!\8G6BY0DQ````,'.`HV<$Z'KV6Z)^C'R,<+!R`*)Q0':BX0DR```
M`(G+P<,%`=J-G`>AZ]ENB?`QZ#'(`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+
MP<H""?N+O"3,````C;0^W+P;CXG/`?.)Q@G7P<8%`?.)_HG/(<8AU\'(`@GW
MB[0DT````(VT-=R\&X\!]XG>P<8%`?>)U@G&(=[!RP*)]8G6(<8)[HNL)-0`
M``"-C"G<O!N/B=V)PP'.">N)^2'[P<$%`<Z)V8G#(>L)RXN,)-@```"-E`K<
MO!N/B>D!T\'/`HGR"?G!P@4A\0'3P<X"B<J)Z2'Y"=&+E"3<````C800W+P;
MCXGZ`<&)V`GRP<`%`<&)T(GZ(=@A\L'+`@G"BX0DX````(V$!=R\&X\!PHG(
MP<`%`<*)\`G8(<B)Q8GP(=@)Z(NL).0```"-O"_<O!N/`?B)U\''!0'XB<^)
MV<'/`@GY(=&)S8G9(?D)Z8NL).@```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.
M`@GR(<+!R`*)U8GZ(?()ZHNL).P```"-G"O<O!N/`=J)R\'#!0':B<.)\`G8
M(<B)Q8GP(=@)Z(NL)/````"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)
MS8G9(?D)Z8NL)/0```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<*)U8GZ
M(?()ZHNL)/@```"-G"O<O!N/`=J)R\'(`L'#!0':B<.)\`G8(<B)Q8GP(=@)
MZ(NL)/P```"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)S8G9(?D)Z8NL
M)``!``"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<+!R`*)U8GZ(?()ZHNL
M)`0!``"-G"O<O!N/B<6)\`':">B)RR'(P<,%`=J)PXGP(>@)V(N<)`@!``"-
MG!_<O!N/`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"0,`0``C;0^
MW+P;CP'SB<;!Q@4!\XG."=:)]XG.(<<AUL'(`@G^B[PD$`$``(V\/=R\&X\!
M_HG?P<<%`?Z)UPG'(=_!RP*)_8G7(<<)[XNL)!0!``"-C"G<O!N/`?F)]\''
M!0'YB<<)WR'WB?V)QR'?">^+K"08`0``C90JW+P;CP'7B<K!S@+!P@4!UXN4
M)!P!``"-E!#6P6+*B=@Q\#'(P<D"`=")^L'"!0'0BY0D(`$``(V<$];!8LJ)
M\C'*,?K!SP(!VHG#P<,%`=J+G"0D`0``C;0>UL%BRHG+,?LQP\'(`@'SB=;!
MQ@4!\XG&BX0D*`$``(V,`=;!8LJ)^#'P,=`!R(G9P<$%`<B)T8N4)"P!``#!
MR0*-E!?6P6+*B?<QSS'?`=>)PL'"!0'7BY0D,`$``,'+`HVT%M;!8LJ)RC':
M,<+!R`(!\HG^P<8%`?*)QHN$)#0!``"-A`'6P6+*B=DQ\3'YP<\"`<&)T,'`
M!0'!BX0D.`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)TXN4)#P!``"+;"00
MP<L"C906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)$`!``"-O!?6P6+*B=HQ
MRC'"P<@"`?J)]\''!0'ZB<>+A"1$`0``C80#UL%BRHG+,?LQ\\'.`@'#B=#!
MP`4!PXN$)$@!``"-C`'6P6+*B?@Q\#'0`<B)V<'!!0'(B=&+E"1,`0``P<D"
MC907UL%BRHGW,<\QW\'+`@'7B<+!P@4!UXN4)%`!``"-M!;6P6+*B<HQVC'"
MP<@"`?*)_L'&!0'RB<:+A"14`0``C80!UL%BRHG9,?$Q^<'/`@'!B=#!P`4!
MP8N$)%@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"1<`0``P<L"C906
MUL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)&`!``"-O!?6P6+*B=HQRC'"P<@"
M`?J)]\''!0'ZB[PD9`$``(V\.];!8LJ)RS'#,?/!S@(!^XG7P<<%`?N+O"1H
M`0``C;P]UL%BR@'/B<$Q\0-T)!0QT<'*`@-4)`P!^8G?`UPD&,''!0'YBWPD
M"`-$)!R)#XE?!(E7"(EW#(E'$(N$)&P!``!E,P44````=`7H@P(``('$?`$`
M`%M>7UW#4^B)WO__@<-I9P``@^P4:F#HQ=G__\<``2-%9\=`!(FKS>_'0`C^
MW+J8QT`,=E0R$,=`$/#ATL/'0!0`````QT`8`````,=`7`````"#Q!A;PU57
M5E.#[!R+;"0XBUPD,(MT)#2-!.T``````T,4<P/_0QB)0Q2+>UR)Z,'H'0%#
M&(U#'(E$)`B%_W1)N4````")Z"GY.<U^`HG(C5,<`?HY\G,*C0P".<YS`_P/
M"XT\!HE\)`PY\G8$.?IR[OR)UXG!*<7SI(M+7`'!B4M<@_E`=77K)_R#_3]^
M/SMT)`AW*(U&0#MT)`B)1"0,<B2+?"0(N1````"#[4#SI8G8Z"#S__^+="0,
MZ\V-0UPYQG/1ZYHY1"0(<];KDCMT)`AV"HM$)`@!Z#G&<H([="0(<PV-!"XY
M1"0(#X)O____BWPD"(GI\Z2):UR#Q!Q;7E]=P^B,WO__!1EF``!55U93@^P<
MBUPD-(MT)#")1"0$BT,4BU,8B<7!Z`,/RHE4)`B#X#^-4QP/S8UX`8E4)`S&
M1`,<@`'Z@_\X?BFY0````"GY_#'`B=?SJHG8C7L<B4PD#.AN\O__BT0D#+D.
M````\ZOK#KDX````*?G\,<")U_.JBT0D"(EK6(E#5(G8Z$+R__^+`X/L#,'H
M&(@&BP/!Z!"(1@&+`XAF`HL#B$8##[9#!XA&!`^W0P:(1@6+0P2(9@:+0P2(
M1@</MD,+B$8(#[=#"HA&"8M#"(AF"HM#"(A&"P^V0P^(1@P/MT,.B$8-BT,,
MB&8.BT,,B$8/#[9#$XA&$`^W0Q*(1A&+0Q"(9A*+0Q"(1A-3BUPD%.@[V?__
M@\0L6UY?7<-3Z!'<__^!P_%D``"#[`CHG]G__X/$"%O#Z$S=__\%V60``%6)
MY5-2C9@@____BP.#^/]T!__0@^L$Z_)86UW#@^P,Z$W<__^#Q`S#````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"]T;7``4$%27U1-4$1)4@!414U01$E2`%1-4`!54T52`%5315).04U%
M`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA
M;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O)6DO)7,`4$%27U1%35``4$%27U!2
M3T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)5
M1P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]
M`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`'!A<BT`)7,E<R5S)7,`
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A
M=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ
M5D524TE/3@`Q+C`T.0!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX
M/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M
M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L
M965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL
M96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D
M8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*
M8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M
M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/
M5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM
M>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP
M871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*
M7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI
M+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG
M+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM
M>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1M86=I8U]P;W,["FEF("@D<VEZ92`\/2`D8VAU;FM?<VEZ
M92D@>PHD;6%G:6-?<&]S(#T@,#L*?2!E;'-I9B`H*&UY("1M(#T@)'-I>F4@
M)2`D8VAU;FM?<VEZ92D@/B`P*2!["B1M86=I8U]P;W,@/2`D<VEZ92`M("1M
M.PI](&5L<V4@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D8VAU;FM?<VEZ93L*
M?0IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96LH7T9(+"`D;6%G:6-?
M<&]S+"`P*3L*<F5A9"A?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M
M86=I8U]P;W,@+3T@)&-H=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S
M(#P@,#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").
M(BP@)&)U9BDL(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER
M95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@
M("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E
M<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T
M<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PIM>2`D8W)C
M(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z
M('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I
M(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL
M96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E"
M.B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]
M('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M
M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT
M("1F:"`D:6YF;RT^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D
M9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D55
M4T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T(#T@,"!U;FQE
M<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=6
M6S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?
M8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@
M('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD[
M"FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T
M($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*
M96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC
M.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A
M9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S
M92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G
M<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS
M:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D
M,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G
M<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@
M)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G
M.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R
M.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]
M*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@
M0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X
M:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O
M=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%2
M1U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID
M:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B
M4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R
M(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM
M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY
M("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@
M/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N
M9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA
M*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I
M;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P
M96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z
M("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E
M($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)
M3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D
M8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N
M*&UY("1F:"P@(CPB+"`D;W5T*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C86-H95]N86UE(#T@)&-T>"T^:&5X
M9&EG97-T.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@
M)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R
M:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)
M0RD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ
M2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHD>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S
M*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^
M(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D
M<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@
M)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M
M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G
M.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68[
M"GT*96QS92!["FUY("1D:6=E<W0@/2!E=F%L"GL*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH;7D@
M)&9H+"`B/"(L("1P<F]G;F%M92D["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8W1X+3YH97AD:6=E<W0["GT@+R\@
M)&UT:6UE.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M)&1I
M9V5S="(["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y]
M(#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL
M92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY
M("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M
M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',[
M"F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D
M("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN
M:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%
M3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$
M14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@
M)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%
M04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI
M('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H
M*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^
M("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("``````<&5R;'AS:2YC`````1L#._`````=
M````U)+__PP!``!DEO__,`$``'R6__\`#````YK__T0!``"/FO__D`$``+Z:
M__^H`0``()O__]0!``#0G/__1`(``#&>__\,`P``K)[__U@#``#GGO__B`,`
M`#R?___4`P``%Z#__U`$```<H/__9`0``-FA__],!0``[J'__V`%``"<HO__
MK`4``/BC___P!0``0J3__Q`&``!MI/__/`8``!RE__^\!@``WZK__R@*``#;
MK?__K`L``#FN__](#```/:[__UP,```9NO__G`P``&NZ___`#```:KO___P,
M``"1O/__0`T``!0``````````7I2``%\"`$;#`0$B`$``"`````<````P)'_
M_Y`#````#@A&#@Q*#PMT!'@`/QH[*C(D(A````!`````+)7__Q@`````````
M2````%0```"WF/__C`````!!#@B%`D$.#(<#00X0A@1##A2#!4X.,'<.-$$.
M.$$./$4.0$@.,&L.%$/##A!!Q@X,0<<."$'%#@0``!0```"@````]YC__R\`
M````0PX@:PX$`"@```"X````#IG__V(`````3`X(A@)!#@R#`T4.(`)-#@Q!
MPPX(0<8.!```;````.0```!$F?__L`$```!!#@B%`D$.#(<#00X0A@1!#A2#
M!4X.0`*:#D1!#DA!#DQ!#E!.#D!5#DQ!#E!2#D!'#D1$#DA%#DQ!#E!.#D!T
M#DQ2#E!(#D`"60X40<,.$$'&#@Q!QPX(0<4.!````,0```!4`0``A)K__V$!
M````00X(A0)!#@R'`T$.$(8$0PX4@P51#J`!8`ZL`4$.L`%(#J`!80ZL`4$.
ML`%(#J`!3PZD`4$.J`%$#JP!1`ZP`4@.H`%%#J0!00ZH`40.K`%$#K`!2`Z@
M`5$.K`%<#K`!20ZT`4D.N`%!#KP!00[``4@.J`%%#JP!00ZP`4@.H`%?#JP!
M00ZP`4@.H`%##JP!00ZP`4@.H`%(#JP!00ZP`5`.H`%8#A1!PPX00<8.#$''
M#@A!Q0X$2````!P"```=F___>P````!!#@B&`D,.#(,#3@Z(`5$.C`%!#I`!
M2`Z``5\.A`%!#H@!0@Z,`4$.D`%(#H`!80X,0<,."$'&#@0``"P```!H`@``
M3)O__SL`````00X(@P).#AQ(#B!,#B1,#BA!#BQ!#C!(#@A!PPX$`$@```"8
M`@``5YO__U4`````00X(A@)!#@R#`TX.'$@.($X.'$(.($8.'$$.&$(.'$D.
M($$.)$<.*$<.+$$.,$@.#$'##@A!Q@X$``!X````Y`(``&";___;`````$$.
M"(4"00X,AP-!#A"&!$$.%(,%40ZP0%<.O$!'#L!`00[$0$<.R$!%#LQ`10[0
M0$@.L$!6#K1`10ZX0$@.O$!!#L!`2`ZP0$D.O$!$#L!`2`ZP0`)(#A1!PPX0
M0<8.#$''#@A!Q0X$````$````&`#``"_F___!0````````#D````=`,``+";
M__^]`0```$$."(4"00X,AP-!#A"&!$$.%(,%40ZP(7$.M"%!#K@A0@Z\(4$.
MP"%(#K`A=`ZT(4$.N"%!#KPA00[`(4@.L"%K#K0A00ZX(4$.O"%(#L`A2`ZP
M(0)`#K0A00ZX(4$.O"%$#L`A00[$(4$.R"%%#LPA2`[0(4@.L"%+#K0A00ZX
M(44.O"%!#L`A2`ZP(54.M"%!#K@A0@Z\(4$.P"%(#K`A5`Z\(4$.P"%(#K`A
M10ZT(4$.N"%!#KPA0@[`(4@.L"%B#A1#PPX00<8.#$''#@A!Q0X$````$```
M`%P$``"%G/__%0````````!(````<`0``(:<__^N`````$$."(<"00X,A@-!
M#A"#!`)2"@X<2`M##AQ'#B!(#A!J#A1!#AA!#AQ!#B!(#A!'PPX,0<8."$''
M#@0`0````+P$``#HG/__7`$```!!#@B'`D8.#(8#00X0@P1.#D`"\PY$2`Y(
M00Y,10Y02`Y`>0X00<,.#$'&#@A!QPX$```<``````4```">__]*`````$$.
M"(,"3@X0>0X(0<,.!"@````@!0``*I[__RL`````00X(@P).#A!(#AQ!#B!(
M#A!)#@A!PPX$````?````$P%```IGO__KP````!!#@B%`D$.#(<#00X0A@1!
M#A2#!4X.,&4*#A1""T$.-$$..$$./$$.0$@.,$\./%H.0%$.1$<.2$$.3$$.
M4%8.%$'##A!!Q@X,0<<."$'%#@1%#C"#!84"A@2'`T,.%$'##A!!Q@X,0<<.
M"$'%#@1H`P``S`4``%B>___#!0```$$."(4"1@X,AP-!#A"&!$$.%(,%40Z0
M@@("A@H.G(("00Z@@@)6"VX.G(("00Z@@@)(#I""`E@.G(("20Z@@@)4#I""
M`D@.E(("0@Z8@@)!#IR"`D4.H(("2PZ0@@)Q#IR"`D$.H(("2`Z0@@)N#IR"
M`D$.H(("2`Z0@@)3#IR"`EL.H(("2@Z<@@)'#IB"`D0.G(("00Z@@@)+#J2"
M`D<.J(("00ZL@@)$#K""`D@.F(("10Z<@@)$#J""`D@.D(("4@Z<@@)!#J""
M`DH.I(("0PZH@@)!#JR"`D@.L(("2`Z0@@)##I2"`D$.F(("10Z<@@)$#J""
M`DP.D(("40Z4@@)##IB"`D$.G(("2`Z@@@)(#I""`GP.G(("00Z@@@)7#I""
M`DP.G(("00Z@@@)&#IR"`D$.F(("00Z<@@)##J""`D@.D(("6@Z4@@)!#IB"
M`D<.G(("10Z@@@)(#I""`FL.E(("00Z8@@)'#IR"`D4.H(("2`Z0@@)6"@Z4
M@@)!#IB"`D(.G(("00Z@@@)(#I""`DP.E(("0@Z8@@)"#IR"`D$.H(("2`Z4
M@@)"#IB"`D@.G(("00Z@@@)(#I""`GX.E(("0@Z8@@)"#IR"`D$.H(("2`Z4
M@@)"#IB"`D$.G(("00Z@@@),#IR"`D$.F(("00Z<@@)!#J""`D0.I(("10M"
M#I2"`D(.F(("0@Z<@@)!#J""`D\.D(("00Z4@@)%#IB"`D@.G(("10Z@@@)(
M#I""`DD.E(("00Z8@@)!#IR"`D$.H(("1PZ0@@)##IR"`D$.H(("1@Z<@@)!
M#IB"`D$.G(("2`Z@@@)(#I""`D<.E(("10Z8@@)&#IR"`DX.H(("2`Z0@@)8
M#I2"`D$.F(("00Z<@@)'#J""`D$.I(("2@ZH@@)!#JR"`D0.L(("2`Z0@@)B
M#I2"`D$.F(("1PZ<@@)!#J""`DH.I(("1`ZH@@)!#JR"`D0.L(("2`Z0@@)!
M#I2"`D$.F(("10Z<@@)$#J""`D@.D(("5PZ4@@)!#IB"`D0.G(("00Z@@@)$
M#J2"`D0.J(("00ZL@@)$#K""`D@.D(("10Z<@@)$#J""`E4.G(("1`Z@@@)(
M#I""`EX.%$'##A!!Q@X,0<<."$'%#@0```"``0``.`D``*^@___\`@```$$.
M"(4"00X,AP-!#A"&!$$.%(,%3@X\2`Y`1@X\0@Y`6PXP5PX\0@Y`30Y$0@Y(
M00Y,00Y02`XP1PX\0@Y`30Y$0@Y(00Y,00Y02`XP;@X\00Y`1PY$1`Y(00Y,
M00Y02`XP=0X\0@Y`1PY$0@Y(10Y,00Y02`XP00XT00XX00X\20Y`2`XP6PX\
M0@Y`1@X\00XX00X\00Y`2`XP2`X\1`Y`2`XT1PXX00X\00Y`2PXP2PX\0@Y`
M1@X\00XX00X\00Y`2`XP0PX\0@Y`30Y$0@Y(00Y,00Y02`XP;0H./$0.0$@.
M-$$..$$./$$.0$\+30X\0@Y`2`XT00XX00X\00Y`2`XP0PH./$(.0$@.-$@.
M.$$./$$.0$8./$(.0$H.-$<..$$./$$.0$8./$(.0%<.,$T./$8.0$@.,$T.
M/$@+00XT00XX10X\1@Y`2`XP3@XT3`XX0@X\1PY`10XP0PX40<,.$$'&#@Q!
MQPX(0<4.!```4````+P*```GHO__7@````!!#@B'`D$.#(8#00X0@P12#AQ!
M#B!0#A!5#A1!#AA'#AQ!#B!(#A!%"L,.#$/&#@A!QPX$10M!PPX,0<8."$''
M#@0`1````!`+``!TBO__V@$```!$#`$`2A`%`G4`1!`'`G5\$`8"=7A#$`,"
M=71,#P-U<`8#L0'!#`$`0<-!QD''0<5##`0$````$````%@+``#IH?__!```
M```````\````;`L``-FA___<"P```$$."(4"0PX,AP-!#A"&!$$.%(,%1@Z0
M`P/+"PX40<,.$$'&#@Q!QPX(0<4.!```(````*P+``!UK?__4@````!!#@B#
M`DX.'$(.('\."$'##@0`.````-`+``"CK?___P````!!#@B%`D$.#(<#00X0
MA@1!#A2#!4,.,`+S#A1!PPX00<8.#$''#@A!Q0X$0`````P,``!FKO__)P$`
M``!+#@B%`D$.#(<#00X0A@1!#A2#!4,.,`*%#CP"@`Y`3`X40<,.$$'&#@Q!
MQPX(0<4.!``<````4`P``$FO__\9`````$$."(,"3@X02`X(0<,.!```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/____\`````_____P`````!````
M`0````$```"\`@``#P```$\$```,`````!````T````=.@``]?[_;XP!```%
M````A`@```8```!D`@``"@```&T$```+````$````!4``````````P```-2>
M```"````P`$``!0````1````%P```*P-```1````]`P``!(```"X````$P``
M``@````8`````````/O__V\!```(^O__;PH`````````````````````````
M````````````````````````````````!)X`````````````-A```$80``!6
M$```9A```'80``"&$```EA```*80``"V$```QA```-80``#F$```]A````81
M```6$0``)A$``#81``!&$0``5A$``&81``!V$0``AA$``)81``"F$0``MA$`
M`,81``#6$0``YA$``/81```&$@``%A(``"82```V$@``1A(``%82``!F$@``
M=A(``(82``"6$@``IA(``+82``#&$@``UA(``.82``#V$@``!A,``!83```F
M$P``-A,``$83``!6$P``9A,``'83``"&$P``EA,``*83``#($P``````````
M```=.@`````````0````````````````````````````````````````````
M`````````````*````5````%00``$$```!=!```80````````/____^[0@``
M1T-#.B`H06QP:6YE(#@N,RXP*2`X+C,N,`!'0T,Z("A!;'!I;F4@.2XR+C`I
M(#DN,BXP```N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YP;'0N9V]T`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S
M`"YD=&]R<P`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````````
M```````````````````````````````````````````````+`````0````(`
M``!T`0``=`$``!<```````````````$`````````$P```/;__V\"````C`$`
M`(P!``#8`````P`````````$````!````!T````+`````@```&0"``!D`@``
M(`8```0````!````!````!`````E`````P````(```"$"```A`@``&T$````
M``````````$`````````+0````D````"````]`P``/0,``"X`````P``````
M```$````"````#8````)````0@```*P-``"L#0``P`$```,````2````!```
M``@````_`````0````8`````$````!```!$```````````````$`````````
M.@````$````&````(!```"`0``"0`P`````````````0````!````$4````!
M````!@```+`3``"P$P``&```````````````"`````@```!.`````0````8`
M``#($P``R!,``%4F``````````````$`````````5`````$````&````'3H`
M`!TZ```,```````````````!`````````%H````!`````@````!`````0```
M2CT`````````````!`````````!B`````0````(```!,?0``3'T``/0`````
M``````````0`````````<`````$````"````0'X``$!^``!P#```````````
M```$`````````'H````!`````P```/2=``#TC0``"```````````````!```
M``````"!`````0````,```#\G0``_(T```@```````````````0`````````
MB`````8````#````!)X```2.``#0````!``````````$````"````$D````!
M`````P```-2>``#4C@``+`$`````````````!`````0```"1`````0````,`
M````H````)```"0```````````````0`````````EP````@````#````0*``
M`"20```T$``````````````@`````````)P````!````,``````````DD```
M-````````````````0````$````!`````P``````````````6)```*4`````
/``````````$`````````
